@@ -1,4 +1,4 @@
-# Copyright 2019-2020 The ASReview Authors. All Rights Reserved.
+# Copyright 2019-2022 The ASReview Authors. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,13 +12,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import logging
-
 from asreview.entry_points.base import BaseEntryPoint
 from asreview.entry_points.base import _base_parser
 from asreview.webapp.run_model import main as main_run_model
 
-
 HOST_NAME = "localhost"
 PORT_NUMBER = 5000
 
@@ -85,7 +82,9 @@ def _lab_parser(prog="lab"):
 
 
 class LABEntryPoint(BaseEntryPoint):
-    description = "Graphical user interface for ASReview."
+    """Entry point to start the ASReview LAB webapp."""
+
+    description = "The ASReview LAB webapp."
 
     def execute(self, argv):
 
@@ -94,17 +93,6 @@ class LABEntryPoint(BaseEntryPoint):
         main(argv)
 
 
-# deprecated oracle class
-class OracleEntryPoint(LABEntryPoint):
-    description = "Graphical user interface for ASReview. (Deprecated)"
-
-    def execute(self, argv):
-
-        logging.warning("Warning: subcommmand 'oracle' is replaced by 'lab'.")
-
-        super(OracleEntryPoint, self).execute(argv)
-
-
 class WebRunModelEntryPoint(BaseEntryPoint):
     description = "Internal use only."
 
