@@ -1,4 +1,4 @@
-# Copyright 2019-2021 The ASReview Authors. All Rights Reserved.
+# Copyright 2019-2022 The ASReview Authors. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,10 +17,10 @@ import logging
 try:
     import tensorflow as tf
     from tensorflow.keras.constraints import MaxNorm
+    from tensorflow.keras.layers import LSTM
     from tensorflow.keras.layers import Dense
     from tensorflow.keras.layers import Embedding
     from tensorflow.keras.layers import Flatten
-    from tensorflow.keras.layers import LSTM
     from tensorflow.keras.layers import MaxPooling1D
     from tensorflow.keras.models import Sequential
     from tensorflow.keras.wrappers.scikit_learn import KerasClassifier
@@ -33,9 +33,11 @@ else:
     except AttributeError:
         logging.getLogger("tensorflow").setLevel(logging.ERROR)
 
+from scipy.sparse import isspmatrix
+
 from asreview.models.classifiers.base import BaseTrainClassifier
 from asreview.models.classifiers.lstm_base import _get_optimizer
-from asreview.utils import _set_class_weight
+from asreview.models.classifiers.utils import _set_class_weight
 
 
 def _check_tensorflow():
@@ -127,6 +129,9 @@ class LSTMPoolClassifier(BaseTrainClassifier):
         # check is tensorflow is available
         _check_tensorflow()
 
+        if isspmatrix(X):
+            X = X.toarray()
+
         sequence_length = X.shape[1]
         if self._model is None or sequence_length != self.sequence_length:
             self.sequence_length = sequence_length
@@ -149,6 +154,26 @@ class LSTMPoolClassifier(BaseTrainClassifier):
             class_weight=self.class_weight,
             verbose=self.verbose)
 
+    def predict_proba(self, X):
+        """Get the inclusion probability for each sample.
+
+        Arguments
+        ---------
+        X: numpy.ndarray
+            Feature matrix to predict.
+
+        Returns
+        -------
+        numpy.ndarray
+            Array with the probabilities for each class, with two
+            columns (class 0, and class 1) and the number of samples rows.
+        """
+
+        if isspmatrix(X):
+            X = X.toarray()
+
+        return self._model.predict_proba(X)
+
     def full_hyper_space(self):
         from hyperopt import hp
 
