@@ -1,4 +1,4 @@
-# Copyright 2019 The ASReview Authors. All Rights Reserved.
+# Copyright 2019-2022 The ASReview Authors. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,22 +15,21 @@
 import gzip
 import io
 import logging
-from multiprocessing import cpu_count
+import time
 from multiprocessing import Process
 from multiprocessing import Queue
+from multiprocessing import cpu_count
 from pathlib import Path
 from urllib.request import urlopen
-import time
 
 import numpy as np
 
-from asreview.utils import get_data_home
 from asreview.models.feature_extraction.base import BaseFeatureExtraction
-
+from asreview.utils import get_data_home
 
 try:
-    from tensorflow.keras.preprocessing.text import Tokenizer
     from tensorflow.keras.preprocessing.sequence import pad_sequences
+    from tensorflow.keras.preprocessing.text import Tokenizer
 except ImportError:
     TF_AVAILABLE = False
 else:
@@ -40,20 +39,20 @@ else:
 def _check_tensorflow():
     if not TF_AVAILABLE:
         raise ImportError(
-            "Install tensorflow package (`pip install tensorflow`) to use"
-            " 'EmbeddingLSTM'.")
+            "Install tensorflow package to use"
+            " Embedding LSTM.")
 
 
 class EmbeddingLSTM(BaseFeatureExtraction):
-    """Class to create embedding matrices for LSTM models.
+    """Embedding LSTM feature extraction technique.
 
-    Feature extraction method for
+    Feature extraction technique for
     :class:`asreview.models.classifiers.LSTMBaseClassifier` and
     :class:`asreview.models.classifiers.LSTMPoolClassifier` models.
 
     .. note::
 
-        This feature extraction algorithm requires ``tensorflow`` to be
+        This feature extraction technique requires ``tensorflow`` to be
         installed. Use ``pip install tensorflow`` or install all optional
         ASReview dependencies with ``pip install asreview[all]``
 
@@ -75,6 +74,7 @@ class EmbeddingLSTM(BaseFeatureExtraction):
     """
 
     name = "embedding-lstm"
+    label = "Embedding LSTM"
 
     def __init__(self,
                  *args,
@@ -126,8 +126,7 @@ class EmbeddingLSTM(BaseFeatureExtraction):
                      "This can take several minutes.")
 
         embedding = load_embedding(embedding_fp, n_jobs=self.n_jobs)
-        embedding_matrix = sample_embedding(embedding, self.word_index)
-        return embedding_matrix
+        return sample_embedding(embedding, self.word_index)
 
     def full_hyper_space(self):
         from hyperopt import hp
